<div id="dsq-recent-comments" class="dsq-widget">
<script type="text/javascript">
{% block config_variables %}
	var disqus_shortname = '{{ shortname }}';
{{ config|safe }}
{% endblock %}
</script>
<script src='//{{ shortname }}.disqus.com/recent_comments_widget.js?num_items={{ num_items }}&hide_avatars={{ hide_avatars }}&avatar_size={{ avatar_size }}&excerpt_length={{ excerpt_length }}'>
</script>
</div>
